--- title: recohut keywords: fastai sidebar: home_sidebar nb_path: "nbs/index.ipynb" ---
{% raw %}
{% endraw %}

a python library for building recommender systems.
Explore the docs »
View Demo · Report Bug · Request Feature

## About The Project [![Product Name Screen Shot][product-screenshot]](https://github.com/RecoHut-Projects/recohut)

(back to top)

### Built With

- Python
- PyTorch
- Numpy
- Pandas
- nbdev
- Jupyter

(back to top)

## Getting Started

To get a local copy up and running follow these simple example steps.

### Prerequisites

- pytorch

      pip install torch

### Installation

    pip install recohut

(back to top)

## Usage

    # import the required modules
    import recohut
    from recohut.datasets import MovieLens
    from recohut.models import MatrixFactorization

    # define the data and model
    data = MovieLens(version='100k', download=True)
    model = MatrixFactorization()

    # train the matrix factorization model
    model.train(data)

    # evaluate the model
    model.evaluate(metrics=['MRR','HR'])

For more examples, please refer to the Documentation and Tutorials.

(back to top)

## Roadmap

- [] RecSys Model Deployment and MLOps features
- [] RL agents and environment specific to recommender systems
- [] Visualization utilities and EDA

See the open issues for a full list of proposed features (and known issues).

(back to top)

## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are greatly appreciated.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement". Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

(back to top)

## License

Distributed under the MIT License. See `LICENSE.txt` for more information.

(back to top)

## Contact

Your Name - Sparsh A.

Project Link: https://github.com/RecoHut-Projects/recohut

(back to top)

## Acknowledgments

- nbdev team for providing supporting tools to build this library.
- colab team for providing running VMs instances for development and testing.

(back to top)